@@ -4,15 +4,17 @@ except ImportError:
     __version__ = "unknown"
 
 from ._widget import (
-    batch_annotator,
+    annotation_saver,
     batch_predict,
     batch_training,
+    batch_utilities,
     batch_workflow,
 )
 
 __all__ = [
-    "batch_annotator",
+    "batch_utilities",
+    "annotation_saver",
     "batch_workflow",
-    "batch_training",
     "batch_predict",
+    "batch_training",
 ]
